@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "zenburn-theme" "2.8.0"
+(define-package "zenburn-theme" "20251012.1810"
   "A low contrast color theme for Emacs."
   ()
-  :url "https://github.com/bbatsov/zenburn-emacs"
-  :commit "8a1f9d28f503615e5d9b3eac59a2f3c14e75fc20"
-  :revdesc "8a1f9d28f503"
+  :url "http://github.com/bbatsov/zenburn-emacs"
+  :commit "b1ef84f7c7102e1d26be67edc6a7ce9698e95f5e"
+  :revdesc "b1ef84f7c710"
   :authors '(("Bozhidar Batsov" . "bozhidar@batsov.com"))
   :maintainers '(("Bozhidar Batsov" . "bozhidar@batsov.com")))
